.. Project NuriKit - Copyright 2023 SNU Compbio Lab.
   SPDX-License-Identifier: Apache-2.0

.. NuriKit documentation master file, created by
   sphinx-quickstart on Thu May 18 09:42:54 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to NuriKit's documentation!
===================================

.. toctree::
   :maxdepth: 3

   nuri
   cpp-bridge

Indices and tables
==================

* :doc:`bib`
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
